package com.caimei.controller;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.LogisticsBatchVo;
import com.caimei.model.vo.OrderVo;
import com.caimei.service.OrderService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/3/26
 */
@Api(tags = "订单相关")
@RestController
@RequestMapping("/order")
public class OrderApi {
    private OrderService orderService;

    @Autowired
    public void setOrderService(OrderService orderService) {
        this.orderService = orderService;
    }

    /**
     * 我的订单
     */
    @ApiOperation("我的订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderState", required = true, value = "1:待付款,2:待发货,3:已发货,4:退货款"),
            @ApiImplicitParam(name = "organizeId", required = true, value = "组织id"),
            @ApiImplicitParam(name = "userId", required = false, value = "机构用户id"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    @GetMapping("/list")
    public ResponseJson<PageInfo<OrderVo>> getOrderList(Integer orderState, Integer userId, Integer organizeId,
                                                        @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                        @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        return orderService.getOrderList(orderState, userId, organizeId, pageNum, pageSize);
    }

    /**
     * 订单详情
     */
    @ApiOperation("订单详情")
    @ApiImplicitParam(name = "orderId", required = true, value = "订单id")
    @GetMapping("/detail")
    public ResponseJson<Map<String, Object>> getOrderDetail(Integer orderId) {
        if (orderId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return orderService.getOrderDetail(orderId);
    }

    /**
     * 查看物流
     */
    @ApiOperation("查看物流")
    @ApiImplicitParam(name = "orderId", required = true, value = "订单id")
    @GetMapping("/logistics")
    public ResponseJson<List<LogisticsBatchVo>> logistics(Integer orderId) {
        if (orderId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return orderService.logistics(orderId);
    }

    /**
     * 确认收货
     */
    @ApiOperation("确认收货")
    @ApiImplicitParam(name = "orderId", required = true, value = "订单id")
    @GetMapping("/affirm")
    public ResponseJson<String> affirmCargo(Integer orderId) {
        return orderService.affirmCargo(orderId);
    }

    /**
     * 分享订单
     */
    @ApiOperation("分享订单")
    @ApiImplicitParam(name = "orderId", required = true, value = "订单id")
    @GetMapping("/share")
    public ResponseJson<String> shareOrder(Integer orderId) {
        return orderService.shareOrder(orderId);
    }

    /**
     * 分享订单,分享码验证通过
     */
    @ApiOperation("分享订单,分享码验证通过")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "shareCode", required = false, value = "分享码"),
            @ApiImplicitParam(name = "code", required = true, value = "微信唯一凭证"),
            @ApiImplicitParam(name = "orderId", required = true, value = "订单id"),
            @ApiImplicitParam(name = "organizeId", required = true, value = "组织id")
    })
    @GetMapping("/shareCode")
    public ResponseJson<Boolean> verifyShareCode(String shareCode, String code, Integer orderId, Integer organizeId) {
        return orderService.verifyShareCode(shareCode, code, orderId, organizeId);
    }

    /**
     * 删除订单
     */
    @GetMapping("/delete")
    @ApiOperation("删除订单")
    @ApiImplicitParam(name = "orderId", required = true, value = "订单id")
    public ResponseJson<String> deleteOrder(Integer orderId) {
        return orderService.deleteOrder(orderId);
    }

    /**
     * 取消订单
     */
    @ApiOperation("取消订单")
    @ApiImplicitParam(name = "orderId", required = true, value = "订单id")
    @GetMapping("/cancel")
    public ResponseJson<String> cancelOrder(Integer orderId) {
        return orderService.cancelOrder(orderId);
    }

    /**
     * 根据关键词获取订单
     */
    @ApiOperation("根据关键词获取订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "searchWord", required = true, value = "搜索关键词"),
            @ApiImplicitParam(name = "organizeId", required = true, value = "组织id"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    @GetMapping("/search")
    public ResponseJson<PageInfo<OrderVo>> getProductsBySearch(String searchWord, Integer organizeId,
                                                               @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                               @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        if (searchWord == null || "".equals(searchWord)) {
            return ResponseJson.error("请输入搜索关键词", null);
        }
        return orderService.searchOrder(searchWord, organizeId, pageNum, pageSize);
    }

    /**
     * 根据组织ID查找历史记录
     */
    @ApiOperation("根据组织ID查找历史记录")
    @ApiImplicitParam(name = "organizeId", required = true, value = "组织id")
    @GetMapping("/searchHistory")
    public ResponseJson<List<String>> getSearchHistory(Integer organizeId) {
        return orderService.getSearchHistory(organizeId);
    }

    /**
     * 根据组织ID删除历史记录
     */
    @ApiOperation("根据组织ID删除历史记录")
    @ApiImplicitParam(name = "organizeId", required = true, value = "组织id")
    @GetMapping("/searchHistory/delete")
    public ResponseJson<String> deleteSearchHistory(Integer organizeId) {
        return orderService.deleteSearchHistory(organizeId);
    }
}
